# TextToOwO
TextToOwO is the best twanswatow to impwess youw fwiend (・`ω´・)
## Installation
### Using pip
```
pip install TextToOwO
```
### Using git
```
pip install git+https://github.com/Zenrac/OwO-Translator
```
## Usage
```py
>>> from TextToOwO import owo
>>> owo.text_to_owo('This is a cool test !')

'This is a coow test ^w^'
```
## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details
